@@ -26,6 +26,20 @@ describe Object, ".method_object" do
     assert klass.call
   end
 
+  it "accepts a block for initialization" do
+    klass = Class.new do
+      method_object :value do
+        @copy = @value
+      end
+
+      attr_reader :copy
+    end
+
+    example = klass.new("expected")
+
+    _(example.copy).must_equal "expected"
+  end
+
   it "passes along any block" do
     klass = Class.new do
       method_object
